@@ -1,10 +1,8 @@
 import json
 import pathlib
 import re
+import warnings
 import weakref
-from abc import ABC
-from abc import abstractmethod
-from collections.abc import Hashable
 from collections.abc import MutableMapping
 from copy import deepcopy
 from enum import Enum
@@ -19,6 +17,9 @@ from typing import Iterator
 from typing import List
 from typing import Optional
 from typing import Union
+from urllib.parse import quote
+from urllib.parse import urlsplit
+from urllib.parse import urlunsplit
 
 from paquo._logging import get_logger
 from paquo._logging import redirect
@@ -40,9 +41,27 @@ from paquo.java import compatibility
 if TYPE_CHECKING:
     import paquo.projects
 
+__all__ = [
+    "ImageProvider",
+    "QuPathImageType",
+    "QuPathProjectImageEntry",
+    "SimpleFileImageId",
+]
+
 _log = get_logger(__name__)
 
 
+def __getattr__(name):
+    if name == "SimpleURIImageProvider":
+        warnings.warn(
+            "SimpleURIImageProvider is deprecated. Please use ImageProvider",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        return ImageProvider
+    raise AttributeError(name)
+
+
 # [URI:java-python]
 # NOTE: pathlib handles URIs a little different to QuPath's java URIs
 #   having looked into it a little bit it seems neither are entirely
@@ -53,39 +72,88 @@ _log = get_logger(__name__)
 def _normalize_pathlib_uris(uri):
     """this will correctly unescape and normalize uri's received from pathlib.Path.as_uri()"""
     # https://docs.oracle.com/javase/7/docs/api/java/net/URI.html section Identities
-    u = URI(uri)
-    return URI(
-        u.getScheme(),
-        u.getUserInfo(),
-        u.getHost(),
-        u.getPort(),
-        u.getPath(),
-        u.getQuery(),
-        u.getFragment()
-    )
+    try:
+        u = URI(uri)
+    except URISyntaxException:
+        try:
+            s = urlsplit(uri)
+            s = s._replace(path=quote(s.path))
+            uri = urlunsplit(s)
+        except ValueError:
+            raise ValueError(f"uri not valid '{uri}'")
+        else:
+            u = URI(uri)
+    scheme = u.getScheme()
+    if scheme != "file":
+        raise ValueError(f"uri unsupported scheme '{uri}'")
+    host = u.getHost()
+    path = str(u.getPath())
+    if host:
+        path = f"////{host}{path}"
+    elif re.match("^//[^/]+/[a-zA-Z][$]/", path):
+        path = f"//{path}"
+    try:
+        x = URI(
+            scheme,
+            u.getUserInfo(),
+            None,
+            u.getPort(),
+            path,
+            u.getQuery(),
+            u.getFragment()
+        )
+    except URISyntaxException:
+        raise ValueError(f"uri syntax error '{uri}'")
+    return x
 
 
-class ImageProvider(ABC):
+SimpleFileImageId = Union[str, pathlib.Path]
+
+
+class ImageProvider:
     """Maps image ids to paths and paths to image ids."""
 
-    @abstractmethod
-    def uri(self, image_id: Hashable) -> Optional[str]:
-        """Returns an URI for an image given an image id tuple."""
-        # default implementation:
-        # -> null uri
-        return None
+    class FilenamePathId(str):
+        """an id that uses the filename as it's identifier"""
+        def __eq__(self, other):
+            return Path(self).name == Path(other).name
 
-    @abstractmethod
-    def id(self, uri: str) -> Hashable:
-        """Returns an image id given an URI."""
-        # default implementation:
-        # -> return filename as image id
-        return ImageProvider.path_from_uri(uri).name
+        def __hash__(self):
+            return hash(Path(self).name)
+
+        def __repr__(self):  # pragma: no cover
+            p = Path(self)
+            return f'FilenamePathId("{p.name}", parent="{p.parent}")'
+
+    class URIString(str):
+        """string uri's can differ in their string representation and still be identical"""
+        # we need some way to normalize uris
+        def __eq__(self, other):  # pragma: no cover
+            return ImageProvider.compare_uris(self, other)
+        __hash__ = str.__hash__  # fixme: this is not correct!
+
+    def uri(self, image_id: SimpleFileImageId) -> Optional['URIString']:
+        """accepts a path and returns a URIString"""
+        if not isinstance(image_id, (Path, str, ImageProvider.FilenamePathId)):
+            raise TypeError("image_id not of correct format")  # pragma: no cover
+        if isinstance(image_id, str) and image_id.startswith("file:/"):
+            # image_id is uri
+            image_id = _normalize_pathlib_uris(image_id)
+            return ImageProvider.URIString(image_id)
+        img_path = pathlib.Path(image_id).absolute().resolve()
+        if not img_path.is_file():
+            return None
+        return ImageProvider.URIString(img_path.as_uri())
+
+    def id(self, uri: URIString) -> str:
+        """accepts a uri string and returns a FilenamePathId"""
+        if not isinstance(uri, (str, ImageProvider.URIString)):
+            raise TypeError("uri not of correct format")  # pragma: no cover
+        return ImageProvider.FilenamePathId(ImageProvider.path_from_uri(uri))
 
-    @abstractmethod
     def rebase(self, *uris: str, **kwargs) -> List[Optional[str]]:
-        """Allows rebasing"""
-        return [self.uri(self.id(uri)) for uri in uris]
+        uri2uri = kwargs.pop('uri2uri', {})
+        return [uri2uri.get(uri, None) for uri in uris]
 
     @staticmethod
     def path_from_uri(uri: str) -> PurePath:
@@ -93,15 +161,17 @@ class ImageProvider(ABC):
         Parses an URI representing a file system path into a Path.
         """
         # TODO: needs way more tests... See note [URI:java-python]
-        try:
-            java_uri = URI(uri)
-        except URISyntaxException:
-            raise ValueError(f"not a valid uri '{uri}'")
+        java_uri = _normalize_pathlib_uris(uri)
         # test current scheme support
         if str(java_uri.getScheme()) != "file":
             raise NotImplementedError("paquo only supports file:/ URIs as of now")
         else:
             path_str = str(java_uri.getPath())
+
+        host = java_uri.getHost()
+        if host:
+            path_str = f"//{host}{path_str}"
+
         # fixme: this should be replaced with something more reliable...
         # check if we encode a windows path
         if re.match(r"/[A-Z]:/[^/]", path_str):
@@ -140,65 +210,6 @@ class ImageProvider(ABC):
         uri_b = _normalize_pathlib_uris(b)
         return bool(uri_a.equals(uri_b))
 
-    @classmethod
-    def __subclasshook__(cls, C):
-        """ImageProviders don't need to derive but only duck-type"""
-        required_methods = ('uri', 'id', 'rebase')
-        if cls is ImageProvider:
-            methods_available = [False] * len(required_methods)
-            for B in C.__mro__:
-                for idx, method in enumerate(required_methods):
-                    methods_available[idx] |= method in B.__dict__
-                if all(methods_available):
-                    return True
-        return NotImplemented
-
-
-SimpleFileImageId = Union[str, pathlib.Path]
-
-
-# noinspection PyMethodMayBeStatic
-class SimpleURIImageProvider:
-    """simple image provider that uses the files uri as it's identifier"""
-
-    class FilenamePathId(str):
-        """an id that uses the filename as it's identifier"""
-        def __eq__(self, other):
-            return Path(self).name == Path(other).name
-
-        def __hash__(self):
-            return hash(Path(self).name)
-
-        def __repr__(self):  # pragma: no cover
-            p = Path(self)
-            return f'FilenamePathId("{p.name}", parent="{p.parent}")'
-
-    class URIString(str):
-        """string uri's can differ in their string representation and still be identical"""
-        # we need some way to normalize uris
-        def __eq__(self, other):  # pragma: no cover
-            return ImageProvider.compare_uris(self, other)
-        __hash__ = str.__hash__  # fixme: this is not correct!
-
-    def uri(self, image_id: SimpleFileImageId) -> Optional['URIString']:
-        """accepts a path and returns a URIString"""
-        if not isinstance(image_id, (Path, str, SimpleURIImageProvider.FilenamePathId)):
-            raise TypeError("image_id not of correct format")  # pragma: no cover
-        img_path = pathlib.Path(image_id).absolute().resolve()
-        if not img_path.is_file():
-            return None
-        return SimpleURIImageProvider.URIString(img_path.as_uri())
-
-    def id(self, uri: URIString) -> str:
-        """accepts a uri string and returns a FilenamePathId"""
-        if not isinstance(uri, (str, SimpleURIImageProvider.URIString)):
-            raise TypeError("uri not of correct format")  # pragma: no cover
-        return SimpleURIImageProvider.FilenamePathId(ImageProvider.path_from_uri(uri))
-
-    def rebase(self, *uris: str, **kwargs) -> List[Optional[str]]:
-        uri2uri = kwargs.pop('uri2uri', {})
-        return [uri2uri.get(uri, None) for uri in uris]
-
 
 # noinspection PyPep8Naming
 class _RecoveredReadOnlyImageServer:
