@@ -1,6 +1,7 @@
 import json
 import math
 from collections.abc import MutableMapping
+from functools import partial
 from typing import Callable
 from typing import Iterator
 from typing import Optional
@@ -76,21 +77,36 @@ def fix_geojson_geometry(geometry: dict) -> dict:
 
 class _MeasurementList(MutableMapping):
 
-    def __init__(self, measurement_list):
+    def __init__(
+        self,
+        measurement_list,
+        *,
+        update_callback: Optional[Callable[[], None]] = None
+    ):
         self._measurement_list = measurement_list
+        self._update_callback = update_callback
 
     def __setitem__(self, k: str, v: float) -> None:
+        if not isinstance(v, float):
+            raise TypeError(f"value must be float, got: {type(v).__name__}")
         self._measurement_list.putMeasurement(k, v)
+        if self._update_callback:
+            self._update_callback()
 
     def __delitem__(self, v: str) -> None:
         if v not in self:
             raise KeyError(v)
         self._measurement_list.removeMeasurements(v)
+        if self._update_callback:
+            self._update_callback()
 
     def __getitem__(self, k: Union[str, int]) -> float:
         if not isinstance(k, (int, str)):
             raise KeyError(f"unsupported key of type {type(k)}")
-        return float(self._measurement_list.getMeasurementValue(k))
+        value = float(self._measurement_list.getMeasurementValue(k))
+        if math.isnan(value) and k not in self:
+            raise KeyError(k)
+        return value
 
     def __contains__(self, item: object) -> bool:
         if not isinstance(item, str):
@@ -105,6 +121,8 @@ class _MeasurementList(MutableMapping):
 
     def clear(self) -> None:
         self._measurement_list.clear()
+        if self._update_callback:
+            self._update_callback()
 
     def __repr__(self):
         return f"Measurements({repr(dict(self))})"
@@ -269,7 +287,14 @@ class _PathROIObject:
 
     @cached_property
     def measurements(self):
-        return _MeasurementList(self.java_object.getMeasurementList())
+        if self._update_callback:
+            cb = partial(self._update_callback, self)
+        else:
+            cb = None
+        return _MeasurementList(
+            self.java_object.getMeasurementList(),
+            update_callback=cb,
+        )
 
     def __repr__(self):
         name = self.name
@@ -281,7 +306,7 @@ class _PathROIObject:
         if path_class:
             out.append(f'class="{path_class.name}"')
         if roi:
-            out.append(f'roi={roi.type}')
+            out.append(f'roi={roi.geom_type}')
         return f"{type(self).__name__}({' '.join(out)})"
 
     def _repr_html_(self):
@@ -316,7 +341,7 @@ class _PathROIObject:
                 span(text=path_class_name),
                 br(),
                 span(text="roi_type: ", style={"font-weight": "bold"}),
-                span(text=roi.type),
+                span(text=roi.geom_type),
                 br(),
                 span(text="roi: ", style={"font-weight": "bold"}),
                 roi_tag,
